/*
 * Enhydra Java Application Server Project
 * 
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 * 
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See 
 * the License for the specific terms governing rights and limitations
 * under the License.
 * 
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 */
package samples;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.Iterator;
import java.util.List;

// Zeus imports
import org.enhydra.zeus.Source;
import org.enhydra.zeus.Marshaller;
import org.enhydra.zeus.Unmarshaller;
import org.enhydra.zeus.result.StreamResult;
import org.enhydra.zeus.source.StreamSource;

// Generated classes
import Artist;
import Songs;
import Song;
import Title;

public class TestUnmarshallSongs {

    public static void main(String[] args) {
        if (args.length != 1) {
            System.out.println("Usage: java samples.TestUnmarshallSongs [songs.xml location]");
            return;
        }

        try {
            Source source = new StreamSource(
                new FileInputStream(new File(args[0])));
            Unmarshaller unmarshaller = new Unmarshaller();
            Object o = unmarshaller.unmarshall(source);

            Songs songs = (Songs)o;
            List songList = songs.getSongList();
            for (Iterator i = songList.iterator(); i.hasNext(); ) {
                Song song = (Song)i.next();
                System.out.println("Song title: " + song.getTitle().getText());
                List artists = song.getArtistList();
                for (Iterator j = artists.iterator(); j.hasNext(); ) {
                    Artist artist = (Artist)j.next();
                    System.out.println("Artist: " + artist.getText());
                }
                System.out.println("-------------------------");
            }

            Marshaller marshaller = new Marshaller();
            marshaller.marshall(o, new StreamResult(new FileOutputStream(new File("output.xml"))));
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}